/*
|------------------------------------------------------------------------------------------
|------------------------------------------------------------------------------------------
| File Name			  : MicroBolt_I2C_EEPROM.c																					
| Author			    : Micromint, Inc.						
| Copyright       : Copyright  2005, Micromint, Inc.																	
| Creation Date		: 12/30/05																							
| Version			    : 1.00																																												
| Spaces per tab	:	2																									
| Description		  : Main C file																																									 
| Revision			  :	Initial																																																						
|------------------------------------------------------------------------------------------
|------------------------------------------------------------------------------------------
*/

/*
|----------------------------------------------------
|     Includes
|----------------------------------------------------
*/

#include <ARM/philips/lpc210x.h>
#include <arm_macros.h>
#include "MicroBolt_I2C_EEPROM.h"
#include "MicroBolt_I2C_Functions.h"
#include "SerialDebugger.h"

/*
|------------------------------------------------------------------------------------------
|     Function        :   main
|     Inputs          :   None
|     Outputs         :   None
|     Purpose         :   Main function for system
|     Author			    :   Micromint, Inc.
|------------------------------------------------------------------------------------------
*/

unsigned char EepromDataValue = 0;
unsigned int Delay, ReadCount;

void main(void)
  {

  __DISABLE_INTERRUPT();                        // Disable all interrupts

/*
|-------------------------
| Config MAM 
|-------------------------
*/
  MAM_CR = 0x00;                                // Turn MAM off (default)
  MAM_TIM = 0x04;                               // Set flash timing to 4 clock cycles

  MAM_CR = 0x02;                                // Fully enable the Memory Accleration Module

/*
|-------------------------
| Config PLL and CCLK 
|-------------------------
*/
  SCB_PLLCFG |= 0x23;				 	   		            // Set to 59 MHz (0x03 is multiply value of 4)
  SCB_PLLCON |= 0x01;                           // Enable the PLL 
  SCB_PLLFEED = 0xAA;					   	  	          // Shadow register copy to enable changes
  SCB_PLLFEED = 0x55;                           // in PLLCON and PLLCFG

/*
|-------------------------
| Config PCLK 
|-------------------------
*/
  SCB_VPBDIV = 0;                               // Peripheral clock is 1/4th Processor clock which equals 14.7456 MHz

/*
|-------------------------
| Configure VIC 
|-------------------------
*/
  VICVectAddr0 = (unsigned)pll_isr;             // Assign the PLL lock ISR vector address
  VICVectCntl0 = INTERRUPT_CHANNEL_FOR_PLL;     // Assign the VIC address to the actual interrupt
  VICIntEnable = INTERRUPT_ENABLE_FOR_PLL;      // Enable the interrupt  

	VICVectAddr1 = (unsigned)I2c_ISR;							// Assign the I2C ISR vector address 
  VICVectCntl1 = INTERRUPT_CHANNEL_FOR_I2C;     // Assign the VIC address to the actual interrupt
  VICIntEnable = INTERRUPT_ENABLE_FOR_I2C;      // Enable the interrupt 

/*
|-------------------------
| Config GPIO 
|-------------------------
*/
  PCB_PINSEL0=0x00000055;                       // Setup with ICCARM App builder - MicroBolt_I2C_EEPROM.bcf (I2C & UART0)   
  PCB_PINSEL1=0x55400000;                       //                                   (Secondary JTAG pins) 

  GPIO_IODIR |= MICROBOLT_LED;                  // Setup MicroBolt LED as output

  GPIO_IOCLR=0xffffffff;                        // Clear all pins to start with

/*
|-------------------------
| Config UART-O 
|-------------------------
*/
  UART0_IER = 0x00000001;	 	                   // Receive interrupts
  UART0_FCR = 0x00000001;	 	                   // Enable the fifos
  UART0_LCR = 0x00000083;	 	                   // Enable the divisor
  UART0_DLM = 0;				                       // Divisor latch MSB (for baud rates < 4800) 
  UART0_DLL = BAUD_RATE_115200;			           // Divisor latch LSB 
  UART0_LCR = 0x00000003;  	                   // Close it, then UART works with divisor

/*
|-------------------------
| Config I2C Master
|-------------------------
*/
  I2C_I2SCLH = 37;                              // I2C clock is 200 KHz (14.7456 MHz/(SCLH + SCLL))
  I2C_I2SCLL = 37;
  I2C_I2CONSET = I2C_ENABLE_BIT;                // Enable the I2C channel

  __ENABLE_INTERRUPT();                         // Enable all interrupts

/*
|-------------------------
| Write to the EEPROM
|-------------------------
*/
	EepromWriteByte(0x0001, 0x03);                // Write the EEPROM at address 0x0001 with data 0x03
	EepromWriteByte(0x00F0, 0x0F);                // Write the EEPROM at address 0x00F0 with data 0x0F
	EepromWriteByte(0x010F, 0x3F);                // Write the EEPROM at address 0x010F with data 0x3F
  EepromWriteByte(0x1FFF, 0xFF);                // Write the EEPROM at address 0x1FFF with data 0xFF

  GPIO_IOSET = MICROBOLT_LED;                   // EEPROM written to, turn on MicroBolt LED
  for (Delay = 0; Delay < 370000; Delay++);     // Delay for 100 mS before starting serial routines
  SerialDebugLed(LED_ON);                       // Turn on MicroBolt serial debugger LED
  SerialDebug(1,"MicroBolt EEPROM demo");       // Output string to MicroBolt Serial Debugger Debug window 1

/*
|----------------------------------------------------
|     Start of application
|----------------------------------------------------
*/
  while(1)                                      // Do this forever
    {
/*
|-------------------------
| Read the EEPROM
|-------------------------
*/
    EepromDataValue = EepromReadByte(0x0001);                     // Read the EEPROM at address 0x0001
    SerialDebug(2,"Address 0x0001 value: 0x%X", EepromDataValue); // Output string to MicroBolt Serial Debugger Debug window 2

    EepromDataValue = EepromReadByte(0x00F0);                     // Read the EEPROM at address 0x00F0
    SerialDebug(3,"Address 0x00F0 value: 0x%X", EepromDataValue); // Output string to MicroBolt Serial Debugger Debug window 3

    EepromDataValue = EepromReadByte(0x010F);                     // Read the EEPROM at address 0x010F
    SerialDebug(7,"Address 0x010F value: 0x%X", EepromDataValue); // Output string to MicroBolt Serial Debugger Debug window 7

    EepromDataValue = EepromReadByte(0x1FFF);                     // Read the EEPROM at address 0x1FFF
    SerialDebug(8,"Address 0x1FFF value: 0x%X", EepromDataValue); // Output string to MicroBolt Serial Debugger Debug window 8 
    
    ReadCount++;                                                  // Increment read counter
    SerialDebug(9,"EEPROM reads: %d", ReadCount);                 // Output string to MicroBolt Serial Debugger Debug window 9 

    for (Delay = 0; Delay < 37000; Delay++);                      // Delay 10 mS between serial data so as not to bog down PC
    }
  }

/*
|------------------------------------------------------------------------------------------
|     Function        :   EepromWriteByte
|     Inputs          :   EEPROM Address and Data
|     Outputs         :   None
|     Purpose         :   Write a byte to the EEPROM
|     Author			    :   Micromint, Inc.
|------------------------------------------------------------------------------------------
*/

void EepromWriteByte(unsigned short EepromAddress, unsigned char EepromData)
  {
  extern unsigned char I2cSlaveAddress;         // I2C slave address
  extern unsigned char I2cBuffer[20];           // I2C application buffer
  extern unsigned char I2cPacketDataSize;       // Number of data bytes for an I2C packet
  extern unsigned char I2cPacketInProgress;	    // I2C Packet in progress flag	
  unsigned short EepromAddressTemp;             // Temp storage register for address calculation

  I2cSlaveAddress = I2C_SLAVE_ADDR_EEPROM;      // Address the EEPROM
  I2cPacketDataSize = 3;                        // How many bytes from the I2c buffer to send

  EepromAddressTemp = EepromAddress & 0xFF00;   // Mask top byte of address
  EepromAddressTemp = EepromAddressTemp >> 8;   // Shift it over by 8
  I2cBuffer[0] = (unsigned char)EepromAddressTemp;        // MSB address byte for EEPROM
  I2cBuffer[1] = (unsigned char)(EepromAddress & 0x00FF); // LSB address byte for EEPROM

  I2cBuffer[2] = EepromData;                    // Data byte for EEPROM

  I2cStart(I2C_WRITE);                          // Send out an I2C Start condition for a Write packet
  while(I2cPacketInProgress == TRUE);           // Wait here for I2C packet to complete 

  I2cSlaveAckPoll();                            // Go ACK poll the EEPROM and wait for data to be written
  }

/*
|------------------------------------------------------------------------------------------
|     Function        :   EepromReadByte
|     Inputs          :   EEPROM Address 
|     Outputs         :   Byte from the EEPROM
|     Purpose         :   Read a byte to the EEPROM
|     Author			    :   Micromint, Inc.
|------------------------------------------------------------------------------------------
*/

unsigned char EepromReadByte(unsigned short EepromAddress)
  {
  extern unsigned char I2cSlaveAddress;         // I2C slave address
  extern unsigned char I2cBuffer[20];           // I2C application buffer
  extern unsigned char I2cPacketDataSize;       // Number of data bytes for an I2C packet
  extern unsigned char I2cPacketInProgress;	    // I2C Packet in progress flag	
  unsigned short EepromAddressTemp;             // Temp register

  I2cSlaveAddress = I2C_SLAVE_ADDR_EEPROM;      // Address the EEPROM
  I2cPacketDataSize = 2;                        // How many bytes from the I2c buffer to send

  EepromAddressTemp = EepromAddress & 0xFF00;   // Mask top byte of address
  EepromAddressTemp = EepromAddressTemp >> 8;   // Shift it over by 8 
  I2cBuffer[0] = (unsigned char)EepromAddressTemp;        // MSB address byte for EEPROM
  I2cBuffer[1] = (unsigned char)(EepromAddress & 0x00FF); // LSB address byte for EEPROM

  I2cStart(I2C_WRITE);                          // Send out an I2C Start condition for a Write packet
  while(I2cPacketInProgress == TRUE);           // Wait here for I2C packet to complete 

  I2cSlaveAddress = I2C_SLAVE_ADDR_EEPROM;      // Address the EEPROM
  I2cPacketDataSize = 1;                        // How many bytes from the I2c buffer to send

  I2cStart(I2C_READ);                           // Send out an I2C Start condition for a Read packet
  while(I2cPacketInProgress == TRUE);           // Wait here for I2C packet to complete

  return(I2cBuffer[0]);                         // Return the byte read from the EEPROM
  }

/*
|------------------------------------------------------------------------------------------
|     Function        :   pll_isr
|     Inputs          :   None
|     Outputs         :   None
|     Purpose         :   Once PLL has locked, connect it and use for system clock
|     Author			    :   Micromint, Inc.
|------------------------------------------------------------------------------------------
*/

#pragma interrupt_handler pll_isr

void pll_isr(void)
  {
  SCB_PLLCON |= 0x02;                           // Connect the PLL 
  SCB_PLLFEED = 0xAA;					   	  	          // Shadow register copy to enable changes
  SCB_PLLFEED = 0x55;                           // in PLLCON and PLLCFG
  VICIntEnClear = PLL_CLR;                      // Clear PLL interrupt flag
  VICVectAddr = VIC_ACK;                        // Acknowledge Interrupt
  }