/*
|------------------------------------------------------------------------------------------
|------------------------------------------------------------------------------------------
| File Name			  : MicroBolt_I2C_EEPROM.h																				
| Author			    : Micromint, Inc.						
| Copyright       : Copyright  2005, Micromint, Inc.																	
| Creation Date		: 12/30/05																							
| Version			    : 1.00																																												
| Spaces per tab	:	2																									
| Description		  : Header file																																									 
| Revision			  :	Initial																																																						
|------------------------------------------------------------------------------------------
|------------------------------------------------------------------------------------------
*/

#ifndef EEPROM_HEADER_H                                   // If not already compiled, compile it                  
#define EEPROM_HEADER_H

/*
|----------------------------------------------------
|     Function prototypes
|----------------------------------------------------
*/

void pll_isr(void);  
void EepromWriteByte(unsigned short EepromAddress, unsigned char EepromData);
unsigned char EepromReadByte(unsigned short EepromAddress);

/*
|----------------------------------------------------
|     Defines
|----------------------------------------------------
*/ 

#define PCLK_FREQ           					14745600          // Crystal frequency in Hz
#define CCLK_FREQ            					58982400          // Frequency after PLL multiplication

#define MICROBOLT_LED                 0x00400000        // On-board Test LED

#define INTERRUPT_CHANNEL_FOR_PLL     0x20 | 12         // The VIC channel for PLL
#define INTERRUPT_ENABLE_FOR_PLL      0x00001000        // The VIC enable for the PLL

#define INTERRUPT_CHANNEL_FOR_I2C     0x20 | 9          // The VIC channel for I2C
#define INTERRUPT_ENABLE_FOR_I2C      0x00000200        // The VIC enable for the I2C

#define VIC_ACK                       0x00000000        // VIC acknowledge 
#define PLL_CLR                       0x00001000        // Clear PLL flag  

#define TRUE                          1
#define FALSE                         0

/*
|----------------------------------------------------
|     Baud rate definitions
|----------------------------------------------------
*/ 

#define BAUD_RATE_4800      208                         // When VPB divider = 0
#define BAUD_RATE_9600      96
#define BAUD_RATE_19200     48
#define BAUD_RATE_38400     24
#define BAUD_RATE_57600     16
#define BAUD_RATE_115200    8

/*
|----------------------------------------------------
|     GPIO definitions
|----------------------------------------------------
*/ 

#define P0_0                					0x00000001
#define P0_1                					0x00000002
#define P0_2                					0x00000004
#define P0_3                					0x00000008
#define P0_4                					0x00000010
#define P0_5                					0x00000020
#define P0_6                					0x00000040
#define P0_7                					0x00000080
#define P0_8                					0x00000100
#define P0_9                					0x00000200
#define P0_10               					0x00000400
#define P0_11               					0x00000800
#define P0_12               					0x00001000
#define P0_13               					0x00002000
#define P0_14               					0x00004000
#define P0_15               					0x00008000
#define P0_16               					0x00010000
#define P0_17               					0x00020000
#define P0_18               					0x00040000
#define P0_19               					0x00080000
#define P0_20               					0x00100000
#define P0_21               					0x00200000
#define P0_22               					0x00400000
#define P0_23               					0x00800000
#define P0_24               					0x01000000
#define P0_25               					0x02000000
#define P0_26               					0x04000000
#define P0_27               					0x08000000
#define P0_28               					0x10000000
#define P0_29               					0x20000000
#define P0_30               					0x40000000
#define P0_31               					0x80000000

/*
|----------------------------------------------------
| MAM - Memory Acceleration Module
|----------------------------------------------------
*/	

#define MAM_CR					(*(REG32 (0xE01FC000)))
#define MAM_TIM					(*(REG32 (0xE01FC004)))  

#endif                                                  // end of EEPROM_HEADER_H   